package VMOMI::HostPowerOperationType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
